All of lore.kernel.org
 help / color / mirror / Atom feed
From: Per Hurtig <per.hurtig@kau.se>
To: netdev@vger.kernel.org
Cc: Per Hurtig <per.hurtig@kau.se>,
	eric.dumazet@gmail.com, anna.brunstrom@kau.se,
	mohammad.rajiullah@kau.se, ncardwell@google.com,
	nanditad@google.com, sergei.shtylyov@cogentembedded.com
Subject: [PATCH] tcp: fixing TLP's FIN recovery
Date: Sat,  7 Jun 2014 16:34:40 +0200	[thread overview]
Message-ID: <1402151680-11434-1-git-send-email-per.hurtig@kau.se> (raw)
In-Reply-To: <539319F6.2090907@cogentembedded.com>

Fix to a problem observed when losing a FIN segment that does not
contain data.  In such situations, TLP is unable to recover from
*any* tail loss and instead adds at least PTO ms to the
retransmission process, i.e., RTO = RTO + PTO.

Signed-off-by: Per Hurtig <per.hurtig@kau.se>
---
 net/ipv4/tcp_output.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/net/ipv4/tcp_output.c b/net/ipv4/tcp_output.c
index d463c35..6573765 100644
--- a/net/ipv4/tcp_output.c
+++ b/net/ipv4/tcp_output.c
@@ -2130,8 +2130,10 @@ void tcp_send_loss_probe(struct sock *sk)
 	if (WARN_ON(!skb || !tcp_skb_pcount(skb)))
 		goto rearm_timer;
 
-	/* Probe with zero data doesn't trigger fast recovery. */
-	if (skb->len > 0)
+	/* Probe with zero data doesn't trigger fast recovery, if FIN
+	 * flag is not set.
+	 */
+	if ((skb->len > 0) || (TCP_SKB_CB(skb)->tcp_flags & TCPHDR_FIN))
 		err = __tcp_retransmit_skb(sk, skb);
 
 	/* Record snd_nxt for loss detection. */
-- 
1.9.1

  reply	other threads:[~2014-06-07 14:35 UTC|newest]

Thread overview: 28+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2014-06-06 18:46 tcp: fixing TLP's FIN recovery Per Hurtig
2014-06-06 19:07 ` Eric Dumazet
2014-06-07 11:10   ` [PATCH] " Per Hurtig
2014-06-07 13:56     ` Sergei Shtylyov
2014-06-07 14:34       ` Per Hurtig [this message]
2014-06-08  2:58         ` Eric Dumazet
2014-06-08  7:41           ` Per Hurtig
2014-06-08 16:35             ` Eric Dumazet
2014-06-09  7:04               ` Nandita Dukkipati
2014-06-09  7:02             ` Nandita Dukkipati
2014-06-09 13:13               ` Per Hurtig
2014-06-09 14:33                 ` Eric Dumazet
2014-06-09 14:39                   ` Eric Dumazet
2014-06-09 14:42                   ` Per Hurtig
2014-06-09 15:04                     ` Eric Dumazet
2014-06-09 15:56                       ` Per Hurtig
2014-06-09 16:15                         ` Eric Dumazet
2014-06-09 16:24                           ` Eric Dumazet
2014-06-09 18:33                             ` Eric Dumazet
2014-06-12 14:21               ` Weiping Pan
2014-06-12 14:32                 ` Eric Dumazet
2014-06-12 15:08                   ` [PATCH v2 1/1] " Per Hurtig
2014-06-12 15:28                     ` Eric Dumazet
2014-06-12 17:36                       ` Nandita Dukkipati
2014-06-12 17:46                         ` Neal Cardwell
2014-06-12 18:06                     ` David Miller
2014-10-07 15:03                       ` Josh Hunt
2014-10-07 20:17                         ` David Miller

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1402151680-11434-1-git-send-email-per.hurtig@kau.se \
    --to=per.hurtig@kau.se \
    --cc=anna.brunstrom@kau.se \
    --cc=eric.dumazet@gmail.com \
    --cc=mohammad.rajiullah@kau.se \
    --cc=nanditad@google.com \
    --cc=ncardwell@google.com \
    --cc=netdev@vger.kernel.org \
    --cc=sergei.shtylyov@cogentembedded.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.